<?php
/*
Plugin Name: Fuzzy Timestamp
Plugin URI: http://w-shadow.com/blog/2010/03/02/fuzzy-timestamp-plugin/
Description: Fuzzify post timestamps by replacing <code>&lt;?php the_time(); ?&gt;</code> with <code>&lt;?php do_action('fuzzy_timestamp'); ?&gt;</code>. Use <code>&lt;?php do_action('fuzzy_timestamp', 'datetime format'); ?&gt;</code> to specify a custom tool-tip/fall-back timestamp format.
Version: 1.1
Author: Janis Elsts
Author URI: http://w-shadow.com/
*/

class FuzzyDate {
	
	var $date_tag = 'abbr';		 //The fuzzy date will be wrapped in this tag. 
								 	 
	var $date_class = 'timeago'; //CSS class for the fuzzy date element. This tells the timeago
								 //plugin which dates to fuzzy-fy.
	
	function FuzzyDate(){
		add_action('template_redirect', array(&$this, 'enqueue_scripts'));
		add_action('wp_footer', array(&$this, 'output_init_script'));
		add_action('fuzzy_timestamp', array(&$this, 'echo_fuzzy_timestamp'));
	}	
	
	function enqueue_scripts() {
		//Enqueue jQuery and the timeago plugin on all public pages
		wp_enqueue_script(
			'jquery-timeago', 
			WP_PLUGIN_URL . '/' . basename(dirname(__FILE__)) . '/jquery.timeago.min.js',
			array('jquery')
		);
	}
	
	function output_init_script(){
		//This script inits the timeago plugin
		?>
		<script type="text/javascript">
			jQuery(document).ready(function() {
			  jQuery("<?php echo $this->date_tag . '.' . $this->date_class; ?>").timeago();
			});
		</script>
		<?php
	}
	
	function echo_fuzzy_timestamp($format = ''){
		//The timeago plugin requires an ISO 8601 date. Note : the 'c' format is only present in PHP 5+.
		$iso_time = get_the_time('c'); 
		//Users who've disabled JS will see the datetime in the default format.
		$normal_time = apply_filters('the_time', get_the_time( $format ), $format);
		
		printf(
			'<%s class="%s" title="%s">%s</abbr>',
			$this->date_tag,
			$this->date_class, 
			$iso_time, 
			$normal_time
		);
	}
}

$ws_fuzzy_date = new FuzzyDate();

?>